'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

exports.default = function () {
  function isReactComponent(superClass) {
    return superClass.matchesPattern('React.Component') || superClass.matchesPattern('Component');
  }

  return {
    visitor: {
      ObjectProperty: function ObjectProperty(path) {
        var node = path.node;

        if (node.computed || node.key.name !== 'propTypes') {
          return;
        }

        var parent = path.findParent(function (parent) {
          if (parent.type !== 'CallExpression') {
            return false;
          }

          return parent.get('callee').matchesPattern('React.createClass');
        });

        if (parent) {
          path.remove();
        }
      },
      ClassProperty: function ClassProperty(path) {
        var node = path.node;
        var scope = path.scope;

        if (node.key.name !== 'propTypes') {
          return;
        }

        var className = scope.block.id.name;
        var binding = scope.getBinding(className);
        var superClass = binding.path.get('superClass');
        if (isReactComponent(superClass)) {
          path.remove();
        }
      },
      AssignmentExpression: function AssignmentExpression(path) {
        var node = path.node;
        var scope = path.scope;
        var left = node.left;

        if (left.computed || !left.property || left.property.name !== 'propTypes') {
          return;
        }

        var className = left.object.name;
        var binding = scope.getBinding(className);
        if (!binding) {
          return;
        }

        if (binding.path.isClassDeclaration()) {
          var superClass = binding.path.get('superClass');
          if (isReactComponent(superClass)) {
            path.remove();
          }
        } else if ((0, _isStatelessComponent2.default)(binding.path)) {
          path.remove();
        }
      }
    }
  };
};

var _isStatelessComponent = require('./is-stateless-component');

var _isStatelessComponent2 = _interopRequireDefault(_isStatelessComponent);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }