'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
function isJSXPath(path) {
  var argument = path.get('argument');
  if (argument.node.type === 'JSXElement') {
    return true;
  }

  if (argument.node.type === 'CallExpression') {
    var callee = argument.get('callee');
    if (callee.matchesPattern('React.createElement')) {
      return true;
    }

    var binding = path.scope.getBinding(callee.node.name);
    if (binding && isReturningJSXElement(binding.path)) {
      return true;
    }
  }

  return false;
}

function isReturningJSXElement(rootPath) {
  var node = rootPath.node;

  if (node.init && node.init.body && node.init.body.type === 'JSXElement') {
    return true;
  }

  var visited = false;
  rootPath.traverse({
    ReturnStatement: function ReturnStatement(path) {
      if (!visited) {
        visited = isJSXPath(path);
      }
    }
  });

  return visited;
}

function isStatelessComponentType(type) {
  return type === 'VariableDeclarator' || type === 'FunctionDeclaration';
}

function isStatelessComponent(path) {
  return isStatelessComponentType(path.node.type) && isReturningJSXElement(path);
}

exports.default = isStatelessComponent;